Commit: dc434bc27316c37bc18559fef72bc5a12b10ec6b
Author: Campbell Barton
Date:   Sat Aug 24 08:54:48 2019 +1000
Branches: master
https://developer.blender.org/rBdc434bc27316c37bc18559fef72bc5a12b10ec6b

Cleanup: correct use of term 'split'

===================================================================

M       source/blender/blenkernel/intern/unit.c
M       source/blender/editors/screen/screen_ops.c
M       source/blender/ikplugin/intern/itasc_plugin.cpp

===================================================================

diff --git a/source/blender/blenkernel/intern/unit.c 
b/source/blender/blenkernel/intern/unit.c
index e30ea687b13..ac1b5e4ab0b 100644
--- a/source/blender/blenkernel/intern/unit.c
+++ b/source/blender/blenkernel/intern/unit.c
@@ -501,12 +501,12 @@ static PreferredUnits 
preferred_units_from_UnitSettings(const UnitSettings *sett
   return units;
 }
 
-static size_t unit_as_string_splitted(char *str,
-                                      int len_max,
-                                      double value,
-                                      int prec,
-                                      const bUnitCollection *usys,
-                                      const bUnitDef *main_unit)
+static size_t unit_as_string_split_pair(char *str,
+                                        int len_max,
+                                        double value,
+                                        int prec,
+                                        const bUnitCollection *usys,
+                                        const bUnitDef *main_unit)
 {
   const bUnitDef *unit_a, *unit_b;
   double value_a, value_b;
@@ -602,7 +602,7 @@ static size_t unit_as_string_main(char *str,
   }
 
   if (split && unit_should_be_split(type)) {
-    int length = unit_as_string_splitted(str, len_max, value, prec, usys, 
main_unit);
+    int length = unit_as_string_split_pair(str, len_max, value, prec, usys, 
main_unit);
     /* failed when length is negative, fallback to no split */
     if (length >= 0) {
       return length;
diff --git a/source/blender/ikplugin/intern/itasc_plugin.cpp 
b/source/blender/ikplugin/intern/itasc_plugin.cpp
index 883919d76ec..2ceedca59f7 100644
--- a/source/blender/ikplugin/intern/itasc_plugin.cpp
+++ b/source/blender/ikplugin/intern/itasc_plugin.cpp
@@ -879,7 +879,7 @@ static bool joint_callback(const iTaSC::Timestamp 
&timestamp,
   bPoseChannel *chan = ikchan->pchan;
   int dof;
 
-  // a channel can be splitted into multiple joints, so we get called multiple
+  // a channel can be split into multiple joints, so we get called multiple
   // times for one channel (this callback is only for 1 joint in the armature)
   // the IK_JointTarget structure is shared between multiple joint constraint
   // and the target joint values is computed only once, remember this in 
jointValid

_______________________________________________
Bf-blender-cvs mailing list
[email protected]
https://lists.blender.org/mailman/listinfo/bf-blender-cvs

Reply via email to
diff --git a/source/blender/editors/screen/screen_ops.c 
b/source/blender/editors/screen/screen_ops.c
index 096870a090a..417bdf84232 100644
--- a/source/blender/editors/screen/screen_ops.c
+++ b/source/blender/editors/screen/screen_ops.c
@@ -3803,7 +3803,7 @@ static int region_quadview_exec(bContext *C, wmOperator 
*op)
 
   /* some rules... */
   if (ar->regiontype != RGN_TYPE_WINDOW) {
-    BKE_report(op->reports, RPT_ERROR, "Only window region can be 4-splitted");
+    BKE_report(op->reports, RPT_ERROR, "Only window region can be 4-split");
   }
   else if (ar->alignment == RGN_ALIGN_QSPLIT) {
     /* Exit quad-view */
@@ -3856,7 +3856,7 @@ static int region_quadview_exec(bContext *C, wmOperator 
*op)
     WM_event_add_notifier(C, NC_SCREEN | NA_EDITED, NULL);
   }
   else if (ar->next) {
-    BKE_report(op->reports, RPT_ERROR, "Only last region can be 4-splitted");
+    BKE_report(op->reports, RPT_ERROR, "Only last region can be 4-split");
   }
   else {
     /* Enter quad-view */
@@ -5029,7 +5029,9 @@ static void region_blend_end(bContext *C, ARegion *ar, 
const bool is_running)
   WM_event_remove_timer(CTX_wm_manager(C), NULL, ar->regiontimer); /* frees 
rgi */
   ar->regiontimer = NULL;
 }
 /* assumes that *ar itself is not a splitted version from previous region */
 void ED_region_visibility_change_update_animated(bContext *C, ScrArea *sa, 
ARegion *ar)
 {
@@ -5029,7 +5029,9 @@ static void region_blend_end(bContext *C, ARegion *ar, 
   ar->regiontimer = NULL;
 }
-/* assumes that *ar itself is not a splitted version from previous region */
+/**
+ * \note Assumes that \a ar itself is not a split version from previous region.
+ */
 void ED_region_visibility_change_update_animated(bContext *C, ScrArea *sa, 
ARegion *ar)
   wmWindowManager *wm = CTX_wm_manager(C);